@@ -296,3 +296,11 @@ class DeletedPost(Exception):
 
     def __str__(self):
         return self.message
+
+
+class set_connect_mail_first(Exception):
+    def __init__(self):
+        self.message = i18n.set_connect_mail_first
+
+    def __str__(self):
+        return self.message
